summaryrefslogtreecommitdiffstats
path: root/server/connection.c
diff options
context:
space:
mode:
authorRyan Bloom <rbb@apache.org>1999-08-31 07:35:52 +0200
committerRyan Bloom <rbb@apache.org>1999-08-31 07:35:52 +0200
commitc37f14ddf32319a7d84a9b573a54ccde8f37c5ff (patch)
tree1f1dd08b2e53226b3b3363beee02eeb57a8061ca /server/connection.c
parentForgot this hook... (diff)
downloadapache2-c37f14ddf32319a7d84a9b573a54ccde8f37c5ff.tar.xz
apache2-c37f14ddf32319a7d84a9b573a54ccde8f37c5ff.zip
Changed pools to contexts. Tested with prefork and pthread mpm's. I'll
check this out tomorrow and make sure everything was checked in correctly. git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@83852 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'server/connection.c')
-rw-r--r--server/connection.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/server/connection.c b/server/connection.c
index a9f0eac514..813824f352 100644
--- a/server/connection.c
+++ b/server/connection.c
@@ -72,7 +72,7 @@ HOOK_STRUCT(
IMPLEMENT_HOOK_VOID(pre_connection,(conn_rec *c),(c))
IMPLEMENT_HOOK_RUN_FIRST(int,process_connection,(conn_rec *c),(c),DECLINED)
/* TODO: re-implement the lingering close stuff */
#define NO_LINGCLOSE
/*
@@ -256,7 +256,7 @@ int ap_process_http_connection(conn_rec *c)
structure, but for now...
*/
-conn_rec *ap_new_connection(pool *p, server_rec *server, BUFF *inout,
+conn_rec *ap_new_connection(ap_context_t *p, server_rec *server, BUFF *inout,
const struct sockaddr_in *remaddr,
const struct sockaddr_in *saddr, long id)
{
@@ -72,7 +72,7 @@ HOOK_STRUCT(
IMPLEMENT_HOOK_VOID(pre_connection,(conn_rec *c),(c))
IMPLEMENT_HOOK_RUN_FIRST(int,process_connection,(conn_rec *c),(c),DECLINED)
-/* TODO: re-implement the lingering close stuff */
+/* TODO: re ap_context_t mplement the lingering close stuff */
#define NO_LINGCLOSE
/*